### FileAutomation

### Documentation

* TODO

---
> Project Kanban \
> https://github.com/orgs/Integration-Automation/projects/2/views/1
> * FileAutomation is used to manager files and dirs.
> * Easily file automation.
> * Automatically backup.
> * Automatically download from Google Drive.
> * Automatically upload to Google Drive.
> * Automatically zip and unzip file.
> * Automatically manager specify file.
> * OS Independent.
> * Remote automation support.
> * Project & Template support.
> * Detailed log file.
> * Scheduler.


## install
> pip install automation_file

## Requires
> python 3.8 or later

### Architecture Diagram
![architecture_diagram](architecture_diagram/FileAutomation.drawio.png)
